pub struct EphemeralPublicKey(pub(crate) AffinePoint);Expand description
An ephemeral public key for Sapling key agreement.
Public keys containing points of small order are not allowed.
It is denoted by epk in the specification. (This type does not
represent KA^{Sapling}.Public, which allows any points, including
of small order).
Tuple Fields
0: AffinePointTrait Implementations
Sourceimpl Clone for EphemeralPublicKey
impl Clone for EphemeralPublicKey
Sourcefn clone(&self) -> EphemeralPublicKey
fn clone(&self) -> EphemeralPublicKey
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EphemeralPublicKey
impl Debug for EphemeralPublicKey
Sourceimpl<'de> Deserialize<'de> for EphemeralPublicKey
impl<'de> Deserialize<'de> for EphemeralPublicKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for EphemeralPublicKey
impl PartialEq for EphemeralPublicKey
Sourceimpl Serialize for EphemeralPublicKey
impl Serialize for EphemeralPublicKey
Sourceimpl TryFrom<[u8; 32]> for EphemeralPublicKey
impl TryFrom<[u8; 32]> for EphemeralPublicKey
Sourcefn try_from(bytes: [u8; 32]) -> Result<Self, Self::Error>
fn try_from(bytes: [u8; 32]) -> Result<Self, Self::Error>
Read an EphemeralPublicKey from a byte array.
Returns an error if the key is non-canonical, or it is of small order.
Consensus
Check that a Output description’s cv and epk are not of small order, i.e. [h_J]cv MUST NOT be 𝒪_J and [h_J]epk MUST NOT be 𝒪_J.
Sourceimpl ZcashDeserialize for EphemeralPublicKey
impl ZcashDeserialize for EphemeralPublicKey
Sourcefn zcash_deserialize<R: Read>(reader: R) -> Result<Self, SerializationError>
fn zcash_deserialize<R: Read>(reader: R) -> Result<Self, SerializationError>
Sourceimpl ZcashSerialize for EphemeralPublicKey
impl ZcashSerialize for EphemeralPublicKey
Sourcefn zcash_serialize_to_vec(&self) -> Result<Vec<u8>, Error>
fn zcash_serialize_to_vec(&self) -> Result<Vec<u8>, Error>
Sourcefn zcash_serialized_size(&self) -> usize
fn zcash_serialized_size(&self) -> usize
self by using a fake writer.impl Copy for EphemeralPublicKey
impl Eq for EphemeralPublicKey
impl StructuralPartialEq for EphemeralPublicKey